use crate::models::work_model::WorkModel;
use crate::services::{serial_service::SerialService, sqlite_service::SqliteService, excel_service::ExcelService};

pub struct WorkService {
    serial_service: SerialService,
    sqlite_service: SqliteService,
    excel_service: ExcelService,
}

impl Default for WorkService {
    fn default() -> Self {
        todo!()
    }
}

impl WorkService {

    fn init_excel_service(&mut self, path: String)->Result<bool, String>{
        return if let Ok(excel_service) = ExcelService::new(&path) {
            self.excel_service = excel_service;
            Ok(true)
        } else {
            Err("Cant Init ExcelService".to_string())
        }
    }

    fn init_sqlite_service(&mut self, db_path: String)->Result<bool, String>{
        return if let Ok(sqlite_service) = SqliteService::new(db_path) {
            self.sqlite_service = sqlite_service;
            Ok(true)
        } else {
            Err("Cant Init SqliteService".to_string())
        }
    }

    fn init_serial_service(&mut self, port_name: String)->Result<bool, String>{
        return if let Ok(serial_service) = SerialService::new(&port_name) {
            self.serial_service = *serial_service;
            Ok(true)
        } else {
            Err("Cant Init SerialService".to_string())
        }
    }

    fn write_imei(&mut self, imei: String) -> Result<bool, String> {
        let write_imei_command = format!("AT+ECCGSN=\"IMEI\",\"{}\"", imei);
        return  self.serial_service.send_command_with_target(write_imei_command, None, "OK".to_string());
    }
    fn write_sn(&mut self, sn: String) -> Result<bool, String> {
        let write_sn_command = format!("AT+ECCGSN=\"SN\",\"{}\"", sn);
        return self.serial_service.send_command_with_target(write_sn_command, None, "OK".to_string());
    }

    fn check_imei(&mut self, imei: &str) -> Result<bool, String> {
        let check_imei_command = "AT+CGSN=1".to_string();
        return self.serial_service.send_command_with_target(check_imei_command, None, imei.to_string());
    }

    fn check_sn(&mut self, sn: &str) -> Result<bool, String> {
        let check_sn_command = "AT+CGSN=0".to_string();
        return self.serial_service.send_command_with_target(check_sn_command, None, sn.to_string());
    }
}